# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from jnpr.healthbot.swagger.api_client import ApiClient


class LicenseApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_iceberg_add_license_from_file(self, license_file, **kwargs):  # noqa: E501
        """Add license from file.  # noqa: E501

        Add license keys from file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_iceberg_add_license_from_file(license_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file license_file: License key file content (required)
        :param str x_iam_token: authentication header object
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_iceberg_add_license_from_file_with_http_info(license_file, **kwargs)  # noqa: E501
        else:
            (data) = self.create_iceberg_add_license_from_file_with_http_info(license_file, **kwargs)  # noqa: E501
            return data

    def create_iceberg_add_license_from_file_with_http_info(self, license_file, **kwargs):  # noqa: E501
        """Add license from file.  # noqa: E501

        Add license keys from file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_iceberg_add_license_from_file_with_http_info(license_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file license_file: License key file content (required)
        :param str x_iam_token: authentication header object
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['license_file', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_iceberg_add_license_from_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'license_file' is set
        if ('license_file' not in params or
                params['license_file'] is None):
            raise ValueError("Missing the required parameter `license_file` when calling `create_iceberg_add_license_from_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'license_file' in params:
            local_var_files['license_file'] = params['license_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/license/keys/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2001',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_iceberg_delete_all_license(self, **kwargs):  # noqa: E501
        """Delete all licenses.  # noqa: E501

        Delete all the previously added license keys.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_iceberg_delete_all_license(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_iceberg_delete_all_license_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.delete_iceberg_delete_all_license_with_http_info(**kwargs)  # noqa: E501
            return data

    def delete_iceberg_delete_all_license_with_http_info(self, **kwargs):  # noqa: E501
        """Delete all licenses.  # noqa: E501

        Delete all the previously added license keys.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_iceberg_delete_all_license_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_iceberg_delete_all_license" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/license/keys/', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_iceberg_delete_license_by_id(self, license_id, **kwargs):  # noqa: E501
        """Delete a license.  # noqa: E501

        Delete a license matching the license id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_iceberg_delete_license_by_id(license_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str license_id: License id (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_iceberg_delete_license_by_id_with_http_info(license_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_iceberg_delete_license_by_id_with_http_info(license_id, **kwargs)  # noqa: E501
            return data

    def delete_iceberg_delete_license_by_id_with_http_info(self, license_id, **kwargs):  # noqa: E501
        """Delete a license.  # noqa: E501

        Delete a license matching the license id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_iceberg_delete_license_by_id_with_http_info(license_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str license_id: License id (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['license_id', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_iceberg_delete_license_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'license_id' is set
        if ('license_id' not in params or
                params['license_id'] is None):
            raise ValueError("Missing the required parameter `license_id` when calling `delete_iceberg_delete_license_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'license_id' in params:
            path_params['license_id'] = params['license_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/license/key/{license_id}/', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_iceberg_get_all_license_id(self, **kwargs):  # noqa: E501
        """List of available license id's.  # noqa: E501

        Get the list of all available license id's.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_iceberg_get_all_license_id(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_iceberg_get_all_license_id_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_iceberg_get_all_license_id_with_http_info(**kwargs)  # noqa: E501
            return data

    def retrieve_iceberg_get_all_license_id_with_http_info(self, **kwargs):  # noqa: E501
        """List of available license id's.  # noqa: E501

        Get the list of all available license id's.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_iceberg_get_all_license_id_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_iceberg_get_all_license_id" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/license/keys/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_iceberg_license_features_info(self, **kwargs):  # noqa: E501
        """Status of all the licensed features.  # noqa: E501

        Get the status of all the licensed features. Also provides the compliance info per feature  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_iceberg_license_features_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: LicenseFeaturesSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_iceberg_license_features_info_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_iceberg_license_features_info_with_http_info(**kwargs)  # noqa: E501
            return data

    def retrieve_iceberg_license_features_info_with_http_info(self, **kwargs):  # noqa: E501
        """Status of all the licensed features.  # noqa: E501

        Get the status of all the licensed features. Also provides the compliance info per feature  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_iceberg_license_features_info_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: LicenseFeaturesSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_iceberg_license_features_info" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/license/status/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LicenseFeaturesSchema',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_iceberg_license_file_by_license_id(self, license_id, **kwargs):  # noqa: E501
        """Download license file.  # noqa: E501

        Download the specified license file based on license id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_iceberg_license_file_by_license_id(license_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str license_id: License id (required)
        :param str x_iam_token: authentication header object
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_iceberg_license_file_by_license_id_with_http_info(license_id, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_iceberg_license_file_by_license_id_with_http_info(license_id, **kwargs)  # noqa: E501
            return data

    def retrieve_iceberg_license_file_by_license_id_with_http_info(self, license_id, **kwargs):  # noqa: E501
        """Download license file.  # noqa: E501

        Download the specified license file based on license id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_iceberg_license_file_by_license_id_with_http_info(license_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str license_id: License id (required)
        :param str x_iam_token: authentication header object
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['license_id', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_iceberg_license_file_by_license_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'license_id' is set
        if ('license_id' not in params or
                params['license_id'] is None):
            raise ValueError("Missing the required parameter `license_id` when calling `retrieve_iceberg_license_file_by_license_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'license_id' in params:
            path_params['license_id'] = params['license_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream', 'application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/license/key/{license_id}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_iceberg_license_key_contents(self, **kwargs):  # noqa: E501
        """Get the contents of all licenses.  # noqa: E501

        Get the license key contents for all the available licenses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_iceberg_license_key_contents(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: LicenseKeysSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_iceberg_license_key_contents_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_iceberg_license_key_contents_with_http_info(**kwargs)  # noqa: E501
            return data

    def retrieve_iceberg_license_key_contents_with_http_info(self, **kwargs):  # noqa: E501
        """Get the contents of all licenses.  # noqa: E501

        Get the license key contents for all the available licenses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_iceberg_license_key_contents_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: LicenseKeysSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_iceberg_license_key_contents" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/license/keys/contents/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LicenseKeysSchema',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_iceberg_license_key_contents_by_id(self, license_id, **kwargs):  # noqa: E501
        """Get the contents of a license.  # noqa: E501

        Get the license key contents by the license id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_iceberg_license_key_contents_by_id(license_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str license_id: License id (required)
        :param str x_iam_token: authentication header object
        :return: LicenseKeySchema
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_iceberg_license_key_contents_by_id_with_http_info(license_id, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_iceberg_license_key_contents_by_id_with_http_info(license_id, **kwargs)  # noqa: E501
            return data

    def retrieve_iceberg_license_key_contents_by_id_with_http_info(self, license_id, **kwargs):  # noqa: E501
        """Get the contents of a license.  # noqa: E501

        Get the license key contents by the license id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_iceberg_license_key_contents_by_id_with_http_info(license_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str license_id: License id (required)
        :param str x_iam_token: authentication header object
        :return: LicenseKeySchema
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['license_id', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_iceberg_license_key_contents_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'license_id' is set
        if ('license_id' not in params or
                params['license_id'] is None):
            raise ValueError("Missing the required parameter `license_id` when calling `retrieve_iceberg_license_key_contents_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'license_id' in params:
            path_params['license_id'] = params['license_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/license/key/{license_id}/contents/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LicenseKeySchema',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_iceberg_replace_license(self, license_raw_keys, **kwargs):  # noqa: E501
        """Update the license.  # noqa: E501

        Update existing license keys with the new one provided in this request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_iceberg_replace_license(license_raw_keys, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LicenseRawKeysSchema license_raw_keys: License raw keys contents (required)
        :param str x_iam_token: authentication header object
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_iceberg_replace_license_with_http_info(license_raw_keys, **kwargs)  # noqa: E501
        else:
            (data) = self.update_iceberg_replace_license_with_http_info(license_raw_keys, **kwargs)  # noqa: E501
            return data

    def update_iceberg_replace_license_with_http_info(self, license_raw_keys, **kwargs):  # noqa: E501
        """Update the license.  # noqa: E501

        Update existing license keys with the new one provided in this request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_iceberg_replace_license_with_http_info(license_raw_keys, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LicenseRawKeysSchema license_raw_keys: License raw keys contents (required)
        :param str x_iam_token: authentication header object
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['license_raw_keys', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_iceberg_replace_license" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'license_raw_keys' is set
        if ('license_raw_keys' not in params or
                params['license_raw_keys'] is None):
            raise ValueError("Missing the required parameter `license_raw_keys` when calling `update_iceberg_replace_license`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'license_raw_keys' in params:
            body_params = params['license_raw_keys']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/license/keys/', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2001',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DeviceSchemaSnmpV3Usm(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'authentication': 'Snmpv3usmuserSchemaAuthentication',
        'authentication_none': 'list[ERRORUNKNOWN]',
        'privacy_none': 'list[ERRORUNKNOWN]',
        'privacy': 'Snmpv3usmuserSchemaPrivacy',
        'snmp_proxy_forwarder': 'DevicegroupSchemaSnmpV3UsmSnmpproxyforwarder',
        'username': 'str'
    }

    attribute_map = {
        'authentication': 'authentication',
        'authentication_none': 'authentication-none',
        'privacy_none': 'privacy-none',
        'privacy': 'privacy',
        'snmp_proxy_forwarder': 'snmp-proxy-forwarder',
        'username': 'username'
    }

    def __init__(self, authentication=None, authentication_none=None, privacy_none=None, privacy=None, snmp_proxy_forwarder=None, username=None):  # noqa: E501
        """DeviceSchemaSnmpV3Usm - a model defined in Swagger"""  # noqa: E501

        self._authentication = None
        self._authentication_none = None
        self._privacy_none = None
        self._privacy = None
        self._snmp_proxy_forwarder = None
        self._username = None
        self.discriminator = None

        if authentication is not None:
            self.authentication = authentication
        if authentication_none is not None:
            self.authentication_none = authentication_none
        if privacy_none is not None:
            self.privacy_none = privacy_none
        if privacy is not None:
            self.privacy = privacy
        if snmp_proxy_forwarder is not None:
            self.snmp_proxy_forwarder = snmp_proxy_forwarder
        self.username = username

    @property
    def authentication(self):
        """Gets the authentication of this DeviceSchemaSnmpV3Usm.  # noqa: E501


        :return: The authentication of this DeviceSchemaSnmpV3Usm.  # noqa: E501
        :rtype: Snmpv3usmuserSchemaAuthentication
        """
        return self._authentication

    @authentication.setter
    def authentication(self, authentication):
        """Sets the authentication of this DeviceSchemaSnmpV3Usm.


        :param authentication: The authentication of this DeviceSchemaSnmpV3Usm.  # noqa: E501
        :type: Snmpv3usmuserSchemaAuthentication
        """

        self._authentication = authentication

    @property
    def authentication_none(self):
        """Gets the authentication_none of this DeviceSchemaSnmpV3Usm.  # noqa: E501

        Configure no authentication for the SNMPv3 user  # noqa: E501

        :return: The authentication_none of this DeviceSchemaSnmpV3Usm.  # noqa: E501
        :rtype: list[ERRORUNKNOWN]
        """
        return self._authentication_none

    @authentication_none.setter
    def authentication_none(self, authentication_none):
        """Sets the authentication_none of this DeviceSchemaSnmpV3Usm.

        Configure no authentication for the SNMPv3 user  # noqa: E501

        :param authentication_none: The authentication_none of this DeviceSchemaSnmpV3Usm.  # noqa: E501
        :type: list[ERRORUNKNOWN]
        """

        self._authentication_none = authentication_none

    @property
    def privacy_none(self):
        """Gets the privacy_none of this DeviceSchemaSnmpV3Usm.  # noqa: E501

        Configure no privacy for the SNMPv3 user  # noqa: E501

        :return: The privacy_none of this DeviceSchemaSnmpV3Usm.  # noqa: E501
        :rtype: list[ERRORUNKNOWN]
        """
        return self._privacy_none

    @privacy_none.setter
    def privacy_none(self, privacy_none):
        """Sets the privacy_none of this DeviceSchemaSnmpV3Usm.

        Configure no privacy for the SNMPv3 user  # noqa: E501

        :param privacy_none: The privacy_none of this DeviceSchemaSnmpV3Usm.  # noqa: E501
        :type: list[ERRORUNKNOWN]
        """

        self._privacy_none = privacy_none

    @property
    def privacy(self):
        """Gets the privacy of this DeviceSchemaSnmpV3Usm.  # noqa: E501


        :return: The privacy of this DeviceSchemaSnmpV3Usm.  # noqa: E501
        :rtype: Snmpv3usmuserSchemaPrivacy
        """
        return self._privacy

    @privacy.setter
    def privacy(self, privacy):
        """Sets the privacy of this DeviceSchemaSnmpV3Usm.


        :param privacy: The privacy of this DeviceSchemaSnmpV3Usm.  # noqa: E501
        :type: Snmpv3usmuserSchemaPrivacy
        """

        self._privacy = privacy

    @property
    def snmp_proxy_forwarder(self):
        """Gets the snmp_proxy_forwarder of this DeviceSchemaSnmpV3Usm.  # noqa: E501


        :return: The snmp_proxy_forwarder of this DeviceSchemaSnmpV3Usm.  # noqa: E501
        :rtype: DevicegroupSchemaSnmpV3UsmSnmpproxyforwarder
        """
        return self._snmp_proxy_forwarder

    @snmp_proxy_forwarder.setter
    def snmp_proxy_forwarder(self, snmp_proxy_forwarder):
        """Sets the snmp_proxy_forwarder of this DeviceSchemaSnmpV3Usm.


        :param snmp_proxy_forwarder: The snmp_proxy_forwarder of this DeviceSchemaSnmpV3Usm.  # noqa: E501
        :type: DevicegroupSchemaSnmpV3UsmSnmpproxyforwarder
        """

        self._snmp_proxy_forwarder = snmp_proxy_forwarder

    @property
    def username(self):
        """Gets the username of this DeviceSchemaSnmpV3Usm.  # noqa: E501

        SNMPv3 username  # noqa: E501

        :return: The username of this DeviceSchemaSnmpV3Usm.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this DeviceSchemaSnmpV3Usm.

        SNMPv3 username  # noqa: E501

        :param username: The username of this DeviceSchemaSnmpV3Usm.  # noqa: E501
        :type: str
        """
        if username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501
        if username is not None and len(username) > 255:
            raise ValueError("Invalid value for `username`, length must be less than or equal to `255`")  # noqa: E501
        if username is not None and len(username) < 1:
            raise ValueError("Invalid value for `username`, length must be greater than or equal to `1`")  # noqa: E501

        self._username = username

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DeviceSchemaSnmpV3Usm, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceSchemaSnmpV3Usm):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Healthbot APIs

    API interface for Healthbot application  # noqa: E501

    OpenAPI spec version: 3.1.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DevicegroupSchemaSnmpV3UsmPrivacy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'passphrase': 'str',
        'protocol': 'str'
    }

    attribute_map = {
        'passphrase': 'passphrase',
        'protocol': 'protocol'
    }

    def __init__(self, passphrase=None, protocol=None):  # noqa: E501
        """DevicegroupSchemaSnmpV3UsmPrivacy - a model defined in Swagger"""  # noqa: E501

        self._passphrase = None
        self._protocol = None
        self.discriminator = None

        self.passphrase = passphrase
        self.protocol = protocol

    @property
    def passphrase(self):
        """Gets the passphrase of this DevicegroupSchemaSnmpV3UsmPrivacy.  # noqa: E501

        Passphrase for SNMPv3 privacy  # noqa: E501

        :return: The passphrase of this DevicegroupSchemaSnmpV3UsmPrivacy.  # noqa: E501
        :rtype: str
        """
        return self._passphrase

    @passphrase.setter
    def passphrase(self, passphrase):
        """Sets the passphrase of this DevicegroupSchemaSnmpV3UsmPrivacy.

        Passphrase for SNMPv3 privacy  # noqa: E501

        :param passphrase: The passphrase of this DevicegroupSchemaSnmpV3UsmPrivacy.  # noqa: E501
        :type: str
        """
        if passphrase is None:
            raise ValueError("Invalid value for `passphrase`, must not be `None`")  # noqa: E501

        self._passphrase = passphrase

    @property
    def protocol(self):
        """Gets the protocol of this DevicegroupSchemaSnmpV3UsmPrivacy.  # noqa: E501

        SNMPv3 privacy protocol  # noqa: E501

        :return: The protocol of this DevicegroupSchemaSnmpV3UsmPrivacy.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this DevicegroupSchemaSnmpV3UsmPrivacy.

        SNMPv3 privacy protocol  # noqa: E501

        :param protocol: The protocol of this DevicegroupSchemaSnmpV3UsmPrivacy.  # noqa: E501
        :type: str
        """
        if protocol is None:
            raise ValueError("Invalid value for `protocol`, must not be `None`")  # noqa: E501
        allowed_values = ["DES", "AES", "AES192", "AES256", "AES192C", "AES256C"]  # noqa: E501
        if protocol not in allowed_values:
            raise ValueError(
                "Invalid value for `protocol` ({0}), must be one of {1}"  # noqa: E501
                .format(protocol, allowed_values)
            )

        self._protocol = protocol

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DevicegroupSchemaSnmpV3UsmPrivacy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicegroupSchemaSnmpV3UsmPrivacy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaArgument(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'argument_name': 'str',
        'mandatory': 'list[object]'
    }

    attribute_map = {
        'argument_name': 'argument-name',
        'mandatory': 'mandatory'
    }

    def __init__(self, argument_name=None, mandatory=None):  # noqa: E501
        """RuleSchemaArgument - a model defined in Swagger"""  # noqa: E501

        self._argument_name = None
        self._mandatory = None
        self.discriminator = None

        self.argument_name = argument_name
        if mandatory is not None:
            self.mandatory = mandatory

    @property
    def argument_name(self):
        """Gets the argument_name of this RuleSchemaArgument.  # noqa: E501

        Name of the argument. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The argument_name of this RuleSchemaArgument.  # noqa: E501
        :rtype: str
        """
        return self._argument_name

    @argument_name.setter
    def argument_name(self, argument_name):
        """Sets the argument_name of this RuleSchemaArgument.

        Name of the argument. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param argument_name: The argument_name of this RuleSchemaArgument.  # noqa: E501
        :type: str
        """
        if argument_name is None:
            raise ValueError("Invalid value for `argument_name`, must not be `None`")  # noqa: E501
        if argument_name is not None and len(argument_name) > 64:
            raise ValueError("Invalid value for `argument_name`, length must be less than or equal to `64`")  # noqa: E501
        if argument_name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', argument_name):  # noqa: E501
            raise ValueError(r"Invalid value for `argument_name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._argument_name = argument_name

    @property
    def mandatory(self):
        """Gets the mandatory of this RuleSchemaArgument.  # noqa: E501

        Flag to indicate a mandatory attribute  # noqa: E501

        :return: The mandatory of this RuleSchemaArgument.  # noqa: E501
        :rtype: list[object]
        """
        return self._mandatory

    @mandatory.setter
    def mandatory(self, mandatory):
        """Sets the mandatory of this RuleSchemaArgument.

        Flag to indicate a mandatory attribute  # noqa: E501

        :param mandatory: The mandatory of this RuleSchemaArgument.  # noqa: E501
        :type: list[object]
        """

        self._mandatory = mandatory

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaArgument, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaArgument):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class LicenseFeatureSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'feature_id': 'int',
        'feature_name': 'str',
        'feature_description': 'str',
        'license_total': 'int',
        'license_remaining': 'int',
        'license_requested': 'int',
        'license_usage': 'int',
        'max_remaining_days': 'int',
        'validity_type': 'str',
        'mode': 'str',
        'compliance': 'bool',
        'end_date': 'int',
        'valid_until': 'str'
    }

    attribute_map = {
        'feature_id': 'feature-id',
        'feature_name': 'feature-name',
        'feature_description': 'feature-description',
        'license_total': 'license-total',
        'license_remaining': 'license-remaining',
        'license_requested': 'license-requested',
        'license_usage': 'license-usage',
        'max_remaining_days': 'max-remaining-days',
        'validity_type': 'validity-type',
        'mode': 'mode',
        'compliance': 'compliance',
        'end_date': 'end-date',
        'valid_until': 'valid-until'
    }

    def __init__(self, feature_id=None, feature_name=None, feature_description=None, license_total=None, license_remaining=None, license_requested=None, license_usage=None, max_remaining_days=None, validity_type=None, mode=None, compliance=None, end_date=None, valid_until=None):  # noqa: E501
        """LicenseFeatureSchema - a model defined in Swagger"""  # noqa: E501

        self._feature_id = None
        self._feature_name = None
        self._feature_description = None
        self._license_total = None
        self._license_remaining = None
        self._license_requested = None
        self._license_usage = None
        self._max_remaining_days = None
        self._validity_type = None
        self._mode = None
        self._compliance = None
        self._end_date = None
        self._valid_until = None
        self.discriminator = None

        if feature_id is not None:
            self.feature_id = feature_id
        self.feature_name = feature_name
        self.feature_description = feature_description
        self.license_total = license_total
        if license_remaining is not None:
            self.license_remaining = license_remaining
        if license_requested is not None:
            self.license_requested = license_requested
        self.license_usage = license_usage
        self.max_remaining_days = max_remaining_days
        self.validity_type = validity_type
        self.mode = mode
        self.compliance = compliance
        self.end_date = end_date
        self.valid_until = valid_until

    @property
    def feature_id(self):
        """Gets the feature_id of this LicenseFeatureSchema.  # noqa: E501

        Unique ID of the licensed feature  # noqa: E501

        :return: The feature_id of this LicenseFeatureSchema.  # noqa: E501
        :rtype: int
        """
        return self._feature_id

    @feature_id.setter
    def feature_id(self, feature_id):
        """Sets the feature_id of this LicenseFeatureSchema.

        Unique ID of the licensed feature  # noqa: E501

        :param feature_id: The feature_id of this LicenseFeatureSchema.  # noqa: E501
        :type: int
        """
        if feature_id is not None and feature_id < 0:  # noqa: E501
            raise ValueError("Invalid value for `feature_id`, must be a value greater than or equal to `0`")  # noqa: E501

        self._feature_id = feature_id

    @property
    def feature_name(self):
        """Gets the feature_name of this LicenseFeatureSchema.  # noqa: E501

        Name of the licensed feature  # noqa: E501

        :return: The feature_name of this LicenseFeatureSchema.  # noqa: E501
        :rtype: str
        """
        return self._feature_name

    @feature_name.setter
    def feature_name(self, feature_name):
        """Sets the feature_name of this LicenseFeatureSchema.

        Name of the licensed feature  # noqa: E501

        :param feature_name: The feature_name of this LicenseFeatureSchema.  # noqa: E501
        :type: str
        """
        if feature_name is None:
            raise ValueError("Invalid value for `feature_name`, must not be `None`")  # noqa: E501

        self._feature_name = feature_name

    @property
    def feature_description(self):
        """Gets the feature_description of this LicenseFeatureSchema.  # noqa: E501

        Brief description of the licensed feature  # noqa: E501

        :return: The feature_description of this LicenseFeatureSchema.  # noqa: E501
        :rtype: str
        """
        return self._feature_description

    @feature_description.setter
    def feature_description(self, feature_description):
        """Sets the feature_description of this LicenseFeatureSchema.

        Brief description of the licensed feature  # noqa: E501

        :param feature_description: The feature_description of this LicenseFeatureSchema.  # noqa: E501
        :type: str
        """
        if feature_description is None:
            raise ValueError("Invalid value for `feature_description`, must not be `None`")  # noqa: E501

        self._feature_description = feature_description

    @property
    def license_total(self):
        """Gets the license_total of this LicenseFeatureSchema.  # noqa: E501

        Total license count for feature  # noqa: E501

        :return: The license_total of this LicenseFeatureSchema.  # noqa: E501
        :rtype: int
        """
        return self._license_total

    @license_total.setter
    def license_total(self, license_total):
        """Sets the license_total of this LicenseFeatureSchema.

        Total license count for feature  # noqa: E501

        :param license_total: The license_total of this LicenseFeatureSchema.  # noqa: E501
        :type: int
        """
        if license_total is None:
            raise ValueError("Invalid value for `license_total`, must not be `None`")  # noqa: E501
        if license_total is not None and license_total < 0:  # noqa: E501
            raise ValueError("Invalid value for `license_total`, must be a value greater than or equal to `0`")  # noqa: E501

        self._license_total = license_total

    @property
    def license_remaining(self):
        """Gets the license_remaining of this LicenseFeatureSchema.  # noqa: E501

        Remaining license count for feature  # noqa: E501

        :return: The license_remaining of this LicenseFeatureSchema.  # noqa: E501
        :rtype: int
        """
        return self._license_remaining

    @license_remaining.setter
    def license_remaining(self, license_remaining):
        """Sets the license_remaining of this LicenseFeatureSchema.

        Remaining license count for feature  # noqa: E501

        :param license_remaining: The license_remaining of this LicenseFeatureSchema.  # noqa: E501
        :type: int
        """
        if license_remaining is not None and license_remaining < 0:  # noqa: E501
            raise ValueError("Invalid value for `license_remaining`, must be a value greater than or equal to `0`")  # noqa: E501

        self._license_remaining = license_remaining

    @property
    def license_requested(self):
        """Gets the license_requested of this LicenseFeatureSchema.  # noqa: E501

        Local requested license count for feature  # noqa: E501

        :return: The license_requested of this LicenseFeatureSchema.  # noqa: E501
        :rtype: int
        """
        return self._license_requested

    @license_requested.setter
    def license_requested(self, license_requested):
        """Sets the license_requested of this LicenseFeatureSchema.

        Local requested license count for feature  # noqa: E501

        :param license_requested: The license_requested of this LicenseFeatureSchema.  # noqa: E501
        :type: int
        """
        if license_requested is not None and license_requested < 0:  # noqa: E501
            raise ValueError("Invalid value for `license_requested`, must be a value greater than or equal to `0`")  # noqa: E501

        self._license_requested = license_requested

    @property
    def license_usage(self):
        """Gets the license_usage of this LicenseFeatureSchema.  # noqa: E501

        License feature usage count  # noqa: E501

        :return: The license_usage of this LicenseFeatureSchema.  # noqa: E501
        :rtype: int
        """
        return self._license_usage

    @license_usage.setter
    def license_usage(self, license_usage):
        """Sets the license_usage of this LicenseFeatureSchema.

        License feature usage count  # noqa: E501

        :param license_usage: The license_usage of this LicenseFeatureSchema.  # noqa: E501
        :type: int
        """
        if license_usage is None:
            raise ValueError("Invalid value for `license_usage`, must not be `None`")  # noqa: E501
        if license_usage is not None and license_usage < 0:  # noqa: E501
            raise ValueError("Invalid value for `license_usage`, must be a value greater than or equal to `0`")  # noqa: E501

        self._license_usage = license_usage

    @property
    def max_remaining_days(self):
        """Gets the max_remaining_days of this LicenseFeatureSchema.  # noqa: E501

        Maximum remaining time of the feature's license in days  # noqa: E501

        :return: The max_remaining_days of this LicenseFeatureSchema.  # noqa: E501
        :rtype: int
        """
        return self._max_remaining_days

    @max_remaining_days.setter
    def max_remaining_days(self, max_remaining_days):
        """Sets the max_remaining_days of this LicenseFeatureSchema.

        Maximum remaining time of the feature's license in days  # noqa: E501

        :param max_remaining_days: The max_remaining_days of this LicenseFeatureSchema.  # noqa: E501
        :type: int
        """
        if max_remaining_days is None:
            raise ValueError("Invalid value for `max_remaining_days`, must not be `None`")  # noqa: E501
        if max_remaining_days is not None and max_remaining_days < 0:  # noqa: E501
            raise ValueError("Invalid value for `max_remaining_days`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_remaining_days = max_remaining_days

    @property
    def validity_type(self):
        """Gets the validity_type of this LicenseFeatureSchema.  # noqa: E501

        License validity type  # noqa: E501

        :return: The validity_type of this LicenseFeatureSchema.  # noqa: E501
        :rtype: str
        """
        return self._validity_type

    @validity_type.setter
    def validity_type(self, validity_type):
        """Sets the validity_type of this LicenseFeatureSchema.

        License validity type  # noqa: E501

        :param validity_type: The validity_type of this LicenseFeatureSchema.  # noqa: E501
        :type: str
        """
        if validity_type is None:
            raise ValueError("Invalid value for `validity_type`, must not be `None`")  # noqa: E501
        allowed_values = ["invalid", "countdown", "date-based", "permanent"]  # noqa: E501
        if validity_type not in allowed_values:
            raise ValueError(
                "Invalid value for `validity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(validity_type, allowed_values)
            )

        self._validity_type = validity_type

    @property
    def mode(self):
        """Gets the mode of this LicenseFeatureSchema.  # noqa: E501

        License mode of operation  # noqa: E501

        :return: The mode of this LicenseFeatureSchema.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this LicenseFeatureSchema.

        License mode of operation  # noqa: E501

        :param mode: The mode of this LicenseFeatureSchema.  # noqa: E501
        :type: str
        """
        if mode is None:
            raise ValueError("Invalid value for `mode`, must not be `None`")  # noqa: E501
        allowed_values = ["invalid", "standalone", "network"]  # noqa: E501
        if mode not in allowed_values:
            raise ValueError(
                "Invalid value for `mode` ({0}), must be one of {1}"  # noqa: E501
                .format(mode, allowed_values)
            )

        self._mode = mode

    @property
    def compliance(self):
        """Gets the compliance of this LicenseFeatureSchema.  # noqa: E501

        Compliance status indicating if the feature usage is in compliance or not  # noqa: E501

        :return: The compliance of this LicenseFeatureSchema.  # noqa: E501
        :rtype: bool
        """
        return self._compliance

    @compliance.setter
    def compliance(self, compliance):
        """Sets the compliance of this LicenseFeatureSchema.

        Compliance status indicating if the feature usage is in compliance or not  # noqa: E501

        :param compliance: The compliance of this LicenseFeatureSchema.  # noqa: E501
        :type: bool
        """
        if compliance is None:
            raise ValueError("Invalid value for `compliance`, must not be `None`")  # noqa: E501

        self._compliance = compliance

    @property
    def end_date(self):
        """Gets the end_date of this LicenseFeatureSchema.  # noqa: E501

        Feature end date timestamp  # noqa: E501

        :return: The end_date of this LicenseFeatureSchema.  # noqa: E501
        :rtype: int
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this LicenseFeatureSchema.

        Feature end date timestamp  # noqa: E501

        :param end_date: The end_date of this LicenseFeatureSchema.  # noqa: E501
        :type: int
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501
        if end_date is not None and end_date < 0:  # noqa: E501
            raise ValueError("Invalid value for `end_date`, must be a value greater than or equal to `0`")  # noqa: E501

        self._end_date = end_date

    @property
    def valid_until(self):
        """Gets the valid_until of this LicenseFeatureSchema.  # noqa: E501

        Validity information of license feature  # noqa: E501

        :return: The valid_until of this LicenseFeatureSchema.  # noqa: E501
        :rtype: str
        """
        return self._valid_until

    @valid_until.setter
    def valid_until(self, valid_until):
        """Sets the valid_until of this LicenseFeatureSchema.

        Validity information of license feature  # noqa: E501

        :param valid_until: The valid_until of this LicenseFeatureSchema.  # noqa: E501
        :type: str
        """
        if valid_until is None:
            raise ValueError("Invalid value for `valid_until`, must not be `None`")  # noqa: E501

        self._valid_until = valid_until

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LicenseFeatureSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LicenseFeatureSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CustompluginSchemaSecurityparametersTls(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ca_profile': 'str',
        'insecure_skip_verify': 'bool',
        'local_certificate_profile': 'str'
    }

    attribute_map = {
        'ca_profile': 'ca-profile',
        'insecure_skip_verify': 'insecure-skip-verify',
        'local_certificate_profile': 'local-certificate-profile'
    }

    def __init__(self, ca_profile=None, insecure_skip_verify=None, local_certificate_profile=None):  # noqa: E501
        """CustompluginSchemaSecurityparametersTls - a model defined in Swagger"""  # noqa: E501

        self._ca_profile = None
        self._insecure_skip_verify = None
        self._local_certificate_profile = None
        self.discriminator = None

        if ca_profile is not None:
            self.ca_profile = ca_profile
        if insecure_skip_verify is not None:
            self.insecure_skip_verify = insecure_skip_verify
        if local_certificate_profile is not None:
            self.local_certificate_profile = local_certificate_profile

    @property
    def ca_profile(self):
        """Gets the ca_profile of this CustompluginSchemaSecurityparametersTls.  # noqa: E501

        CA profile name  # noqa: E501

        :return: The ca_profile of this CustompluginSchemaSecurityparametersTls.  # noqa: E501
        :rtype: str
        """
        return self._ca_profile

    @ca_profile.setter
    def ca_profile(self, ca_profile):
        """Sets the ca_profile of this CustompluginSchemaSecurityparametersTls.

        CA profile name  # noqa: E501

        :param ca_profile: The ca_profile of this CustompluginSchemaSecurityparametersTls.  # noqa: E501
        :type: str
        """

        self._ca_profile = ca_profile

    @property
    def insecure_skip_verify(self):
        """Gets the insecure_skip_verify of this CustompluginSchemaSecurityparametersTls.  # noqa: E501

        Use TLS but skip verification of certificate chain and host  # noqa: E501

        :return: The insecure_skip_verify of this CustompluginSchemaSecurityparametersTls.  # noqa: E501
        :rtype: bool
        """
        return self._insecure_skip_verify

    @insecure_skip_verify.setter
    def insecure_skip_verify(self, insecure_skip_verify):
        """Sets the insecure_skip_verify of this CustompluginSchemaSecurityparametersTls.

        Use TLS but skip verification of certificate chain and host  # noqa: E501

        :param insecure_skip_verify: The insecure_skip_verify of this CustompluginSchemaSecurityparametersTls.  # noqa: E501
        :type: bool
        """

        self._insecure_skip_verify = insecure_skip_verify

    @property
    def local_certificate_profile(self):
        """Gets the local_certificate_profile of this CustompluginSchemaSecurityparametersTls.  # noqa: E501

        Local certificate profile name  # noqa: E501

        :return: The local_certificate_profile of this CustompluginSchemaSecurityparametersTls.  # noqa: E501
        :rtype: str
        """
        return self._local_certificate_profile

    @local_certificate_profile.setter
    def local_certificate_profile(self, local_certificate_profile):
        """Sets the local_certificate_profile of this CustompluginSchemaSecurityparametersTls.

        Local certificate profile name  # noqa: E501

        :param local_certificate_profile: The local_certificate_profile of this CustompluginSchemaSecurityparametersTls.  # noqa: E501
        :type: str
        """

        self._local_certificate_profile = local_certificate_profile

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustompluginSchemaSecurityparametersTls, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustompluginSchemaSecurityparametersTls):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaRulepropertiesHelperfiles(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file_type': 'str',
        'list_of_files': 'list[str]'
    }

    attribute_map = {
        'file_type': 'file-type',
        'list_of_files': 'list-of-files'
    }

    def __init__(self, file_type=None, list_of_files=None):  # noqa: E501
        """RuleSchemaRulepropertiesHelperfiles - a model defined in Swagger"""  # noqa: E501

        self._file_type = None
        self._list_of_files = None
        self.discriminator = None

        self.file_type = file_type
        self.list_of_files = list_of_files

    @property
    def file_type(self):
        """Gets the file_type of this RuleSchemaRulepropertiesHelperfiles.  # noqa: E501


        :return: The file_type of this RuleSchemaRulepropertiesHelperfiles.  # noqa: E501
        :rtype: str
        """
        return self._file_type

    @file_type.setter
    def file_type(self, file_type):
        """Sets the file_type of this RuleSchemaRulepropertiesHelperfiles.


        :param file_type: The file_type of this RuleSchemaRulepropertiesHelperfiles.  # noqa: E501
        :type: str
        """
        if file_type is None:
            raise ValueError("Invalid value for `file_type`, must not be `None`")  # noqa: E501
        allowed_values = ["schema", "mib", "other"]  # noqa: E501
        if file_type not in allowed_values:
            raise ValueError(
                "Invalid value for `file_type` ({0}), must be one of {1}"  # noqa: E501
                .format(file_type, allowed_values)
            )

        self._file_type = file_type

    @property
    def list_of_files(self):
        """Gets the list_of_files of this RuleSchemaRulepropertiesHelperfiles.  # noqa: E501


        :return: The list_of_files of this RuleSchemaRulepropertiesHelperfiles.  # noqa: E501
        :rtype: list[str]
        """
        return self._list_of_files

    @list_of_files.setter
    def list_of_files(self, list_of_files):
        """Sets the list_of_files of this RuleSchemaRulepropertiesHelperfiles.


        :param list_of_files: The list_of_files of this RuleSchemaRulepropertiesHelperfiles.  # noqa: E501
        :type: list[str]
        """
        if list_of_files is None:
            raise ValueError("Invalid value for `list_of_files`, must not be `None`")  # noqa: E501

        self._list_of_files = list_of_files

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaRulepropertiesHelperfiles, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaRulepropertiesHelperfiles):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SflowSchemaSflowSample(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enterprise': 'int',
        'field': 'list[SflowSchemaSflowField]',
        'format': 'int',
        'record_type': 'str',
        'sample_name': 'str'
    }

    attribute_map = {
        'enterprise': 'enterprise',
        'field': 'field',
        'format': 'format',
        'record_type': 'record-type',
        'sample_name': 'sample-name'
    }

    def __init__(self, enterprise=None, field=None, format=None, record_type=None, sample_name=None):  # noqa: E501
        """SflowSchemaSflowSample - a model defined in Swagger"""  # noqa: E501

        self._enterprise = None
        self._field = None
        self._format = None
        self._record_type = None
        self._sample_name = None
        self.discriminator = None

        self.enterprise = enterprise
        self.field = field
        self.format = format
        if record_type is not None:
            self.record_type = record_type
        self.sample_name = sample_name

    @property
    def enterprise(self):
        """Gets the enterprise of this SflowSchemaSflowSample.  # noqa: E501

        Enterprise to which sample belongs  # noqa: E501

        :return: The enterprise of this SflowSchemaSflowSample.  # noqa: E501
        :rtype: int
        """
        return self._enterprise

    @enterprise.setter
    def enterprise(self, enterprise):
        """Sets the enterprise of this SflowSchemaSflowSample.

        Enterprise to which sample belongs  # noqa: E501

        :param enterprise: The enterprise of this SflowSchemaSflowSample.  # noqa: E501
        :type: int
        """
        if enterprise is None:
            raise ValueError("Invalid value for `enterprise`, must not be `None`")  # noqa: E501

        self._enterprise = enterprise

    @property
    def field(self):
        """Gets the field of this SflowSchemaSflowSample.  # noqa: E501

        List of fields  # noqa: E501

        :return: The field of this SflowSchemaSflowSample.  # noqa: E501
        :rtype: list[SflowSchemaSflowField]
        """
        return self._field

    @field.setter
    def field(self, field):
        """Sets the field of this SflowSchemaSflowSample.

        List of fields  # noqa: E501

        :param field: The field of this SflowSchemaSflowSample.  # noqa: E501
        :type: list[SflowSchemaSflowField]
        """
        if field is None:
            raise ValueError("Invalid value for `field`, must not be `None`")  # noqa: E501

        self._field = field

    @property
    def format(self):
        """Gets the format of this SflowSchemaSflowSample.  # noqa: E501

        Format of sample  # noqa: E501

        :return: The format of this SflowSchemaSflowSample.  # noqa: E501
        :rtype: int
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this SflowSchemaSflowSample.

        Format of sample  # noqa: E501

        :param format: The format of this SflowSchemaSflowSample.  # noqa: E501
        :type: int
        """
        if format is None:
            raise ValueError("Invalid value for `format`, must not be `None`")  # noqa: E501

        self._format = format

    @property
    def record_type(self):
        """Gets the record_type of this SflowSchemaSflowSample.  # noqa: E501

        Type of records in this sample type  # noqa: E501

        :return: The record_type of this SflowSchemaSflowSample.  # noqa: E501
        :rtype: str
        """
        return self._record_type

    @record_type.setter
    def record_type(self, record_type):
        """Sets the record_type of this SflowSchemaSflowSample.

        Type of records in this sample type  # noqa: E501

        :param record_type: The record_type of this SflowSchemaSflowSample.  # noqa: E501
        :type: str
        """
        allowed_values = ["flow", "counter"]  # noqa: E501
        if record_type not in allowed_values:
            raise ValueError(
                "Invalid value for `record_type` ({0}), must be one of {1}"  # noqa: E501
                .format(record_type, allowed_values)
            )

        self._record_type = record_type

    @property
    def sample_name(self):
        """Gets the sample_name of this SflowSchemaSflowSample.  # noqa: E501

        Name of sample type  # noqa: E501

        :return: The sample_name of this SflowSchemaSflowSample.  # noqa: E501
        :rtype: str
        """
        return self._sample_name

    @sample_name.setter
    def sample_name(self, sample_name):
        """Sets the sample_name of this SflowSchemaSflowSample.

        Name of sample type  # noqa: E501

        :param sample_name: The sample_name of this SflowSchemaSflowSample.  # noqa: E501
        :type: str
        """
        if sample_name is None:
            raise ValueError("Invalid value for `sample_name`, must not be `None`")  # noqa: E501

        self._sample_name = sample_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SflowSchemaSflowSample, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SflowSchemaSflowSample):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaSyslog(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'pattern_set': 'str',
        'maximum_hold_period': 'str'
    }

    attribute_map = {
        'pattern_set': 'pattern-set',
        'maximum_hold_period': 'maximum-hold-period'
    }

    def __init__(self, pattern_set=None, maximum_hold_period='1s'):  # noqa: E501
        """RuleSchemaSyslog - a model defined in Swagger"""  # noqa: E501

        self._pattern_set = None
        self._maximum_hold_period = None
        self.discriminator = None

        self.pattern_set = pattern_set
        if maximum_hold_period is not None:
            self.maximum_hold_period = maximum_hold_period

    @property
    def pattern_set(self):
        """Gets the pattern_set of this RuleSchemaSyslog.  # noqa: E501

        Pattern-set applicable for this sensor  # noqa: E501

        :return: The pattern_set of this RuleSchemaSyslog.  # noqa: E501
        :rtype: str
        """
        return self._pattern_set

    @pattern_set.setter
    def pattern_set(self, pattern_set):
        """Sets the pattern_set of this RuleSchemaSyslog.

        Pattern-set applicable for this sensor  # noqa: E501

        :param pattern_set: The pattern_set of this RuleSchemaSyslog.  # noqa: E501
        :type: str
        """
        if pattern_set is None:
            raise ValueError("Invalid value for `pattern_set`, must not be `None`")  # noqa: E501

        self._pattern_set = pattern_set

    @property
    def maximum_hold_period(self):
        """Gets the maximum_hold_period of this RuleSchemaSyslog.  # noqa: E501

        Maximum time (in units of seconds/minutes/hours/days) system will wait for all fields to arrive before flushing all the field data. Default is 1 second  # noqa: E501

        :return: The maximum_hold_period of this RuleSchemaSyslog.  # noqa: E501
        :rtype: str
        """
        return self._maximum_hold_period

    @maximum_hold_period.setter
    def maximum_hold_period(self, maximum_hold_period):
        """Sets the maximum_hold_period of this RuleSchemaSyslog.

        Maximum time (in units of seconds/minutes/hours/days) system will wait for all fields to arrive before flushing all the field data. Default is 1 second  # noqa: E501

        :param maximum_hold_period: The maximum_hold_period of this RuleSchemaSyslog.  # noqa: E501
        :type: str
        """
        if maximum_hold_period is not None and not re.search(r'[1-9][0-9]*[smhd]', maximum_hold_period):  # noqa: E501
            raise ValueError(r"Invalid value for `maximum_hold_period`, must be a follow pattern or equal to `/[1-9][0-9]*[smhd]/`")  # noqa: E501

        self._maximum_hold_period = maximum_hold_period

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaSyslog, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaSyslog):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from jnpr.healthbot.swagger.api.administration_api import AdministrationApi
from jnpr.healthbot.swagger.api.authentication_api import AuthenticationApi
from jnpr.healthbot.swagger.api.configuration_api import ConfigurationApi
from jnpr.healthbot.swagger.api.data_store_api import DataStoreApi
from jnpr.healthbot.swagger.api.debug_api import DebugApi
from jnpr.healthbot.swagger.api.default_api import DefaultApi
from jnpr.healthbot.swagger.api.documentation_api import DocumentationApi
from jnpr.healthbot.swagger.api.facts_api import FactsApi
from jnpr.healthbot.swagger.api.instance_schedule_state_api import InstanceScheduleStateApi
from jnpr.healthbot.swagger.api.license_api import LicenseApi
from jnpr.healthbot.swagger.api.logs_api import LogsApi
from jnpr.healthbot.swagger.api.organization_api import OrganizationApi
from jnpr.healthbot.swagger.api.services_api import ServicesApi
from jnpr.healthbot.swagger.api.system_api import SystemApi
from jnpr.healthbot.swagger.api.workflow_api import WorkflowApi
from jnpr.healthbot.swagger.api.workflow_instance_api import WorkflowInstanceApi
from jnpr.healthbot.swagger.api.workflow_statistics_api import WorkflowStatisticsApi



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ReportSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'capture_fields': 'list[str]',
        'destination': 'list[str]',
        'format': 'str',
        'graph_canvas': 'list[ReportSchemaGraphcanvas]',
        'name': 'str',
        'schedule': 'list[str]'
    }

    attribute_map = {
        'capture_fields': 'capture-fields',
        'destination': 'destination',
        'format': 'format',
        'graph_canvas': 'graph-canvas',
        'name': 'name',
        'schedule': 'schedule'
    }

    def __init__(self, capture_fields=None, destination=None, format=None, graph_canvas=None, name=None, schedule=None):  # noqa: E501
        """ReportSchema - a model defined in Swagger"""  # noqa: E501

        self._capture_fields = None
        self._destination = None
        self._format = None
        self._graph_canvas = None
        self._name = None
        self._schedule = None
        self.discriminator = None

        if capture_fields is not None:
            self.capture_fields = capture_fields
        self.destination = destination
        self.format = format
        if graph_canvas is not None:
            self.graph_canvas = graph_canvas
        self.name = name
        self.schedule = schedule

    @property
    def capture_fields(self):
        """Gets the capture_fields of this ReportSchema.  # noqa: E501


        :return: The capture_fields of this ReportSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._capture_fields

    @capture_fields.setter
    def capture_fields(self, capture_fields):
        """Sets the capture_fields of this ReportSchema.


        :param capture_fields: The capture_fields of this ReportSchema.  # noqa: E501
        :type: list[str]
        """

        self._capture_fields = capture_fields

    @property
    def destination(self):
        """Gets the destination of this ReportSchema.  # noqa: E501


        :return: The destination of this ReportSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this ReportSchema.


        :param destination: The destination of this ReportSchema.  # noqa: E501
        :type: list[str]
        """
        if destination is None:
            raise ValueError("Invalid value for `destination`, must not be `None`")  # noqa: E501

        self._destination = destination

    @property
    def format(self):
        """Gets the format of this ReportSchema.  # noqa: E501

        Generated report format  # noqa: E501

        :return: The format of this ReportSchema.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this ReportSchema.

        Generated report format  # noqa: E501

        :param format: The format of this ReportSchema.  # noqa: E501
        :type: str
        """
        if format is None:
            raise ValueError("Invalid value for `format`, must not be `None`")  # noqa: E501
        allowed_values = ["json", "html", "pdf"]  # noqa: E501
        if format not in allowed_values:
            raise ValueError(
                "Invalid value for `format` ({0}), must be one of {1}"  # noqa: E501
                .format(format, allowed_values)
            )

        self._format = format

    @property
    def graph_canvas(self):
        """Gets the graph_canvas of this ReportSchema.  # noqa: E501

        Canvas name  # noqa: E501

        :return: The graph_canvas of this ReportSchema.  # noqa: E501
        :rtype: list[ReportSchemaGraphcanvas]
        """
        return self._graph_canvas

    @graph_canvas.setter
    def graph_canvas(self, graph_canvas):
        """Sets the graph_canvas of this ReportSchema.

        Canvas name  # noqa: E501

        :param graph_canvas: The graph_canvas of this ReportSchema.  # noqa: E501
        :type: list[ReportSchemaGraphcanvas]
        """

        self._graph_canvas = graph_canvas

    @property
    def name(self):
        """Gets the name of this ReportSchema.  # noqa: E501

        Name of the report  # noqa: E501

        :return: The name of this ReportSchema.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ReportSchema.

        Name of the report  # noqa: E501

        :param name: The name of this ReportSchema.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', name):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._name = name

    @property
    def schedule(self):
        """Gets the schedule of this ReportSchema.  # noqa: E501


        :return: The schedule of this ReportSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """Sets the schedule of this ReportSchema.


        :param schedule: The schedule of this ReportSchema.  # noqa: E501
        :type: list[str]
        """
        if schedule is None:
            raise ValueError("Invalid value for `schedule`, must not be `None`")  # noqa: E501

        self._schedule = schedule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReportSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Healthbot APIs

    API interface for Healthbot application  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: healthbot-hackers@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaFormula1And(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'left_vector': 'str',
        'right_vector': 'str'
    }

    attribute_map = {
        'left_vector': 'left-vector',
        'right_vector': 'right-vector'
    }

    def __init__(self, left_vector=None, right_vector=None):  # noqa: E501
        """RuleSchemaFormula1And - a model defined in Swagger"""  # noqa: E501

        self._left_vector = None
        self._right_vector = None
        self.discriminator = None

        self.left_vector = left_vector
        self.right_vector = right_vector

    @property
    def left_vector(self):
        """Gets the left_vector of this RuleSchemaFormula1And.  # noqa: E501

        Vector name. Pattern for giving vector name is @[a-z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The left_vector of this RuleSchemaFormula1And.  # noqa: E501
        :rtype: str
        """
        return self._left_vector

    @left_vector.setter
    def left_vector(self, left_vector):
        """Sets the left_vector of this RuleSchemaFormula1And.

        Vector name. Pattern for giving vector name is @[a-z][a-zA-Z0-9_-]*  # noqa: E501

        :param left_vector: The left_vector of this RuleSchemaFormula1And.  # noqa: E501
        :type: str
        """
        if left_vector is None:
            raise ValueError("Invalid value for `left_vector`, must not be `None`")  # noqa: E501
        if left_vector is not None and not re.search('^@[a-z][a-zA-Z0-9_-]*$', left_vector):  # noqa: E501
            raise ValueError("Invalid value for `left_vector`, must be a follow pattern or equal to `/^@[a-z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._left_vector = left_vector

    @property
    def right_vector(self):
        """Gets the right_vector of this RuleSchemaFormula1And.  # noqa: E501

        Vector name. Pattern for giving vector name is @[a-z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The right_vector of this RuleSchemaFormula1And.  # noqa: E501
        :rtype: str
        """
        return self._right_vector

    @right_vector.setter
    def right_vector(self, right_vector):
        """Sets the right_vector of this RuleSchemaFormula1And.

        Vector name. Pattern for giving vector name is @[a-z][a-zA-Z0-9_-]*  # noqa: E501

        :param right_vector: The right_vector of this RuleSchemaFormula1And.  # noqa: E501
        :type: str
        """
        if right_vector is None:
            raise ValueError("Invalid value for `right_vector`, must not be `None`")  # noqa: E501
        if right_vector is not None and not re.search('^@[a-z][a-zA-Z0-9_-]*$', right_vector):  # noqa: E501
            raise ValueError("Invalid value for `right_vector`, must be a follow pattern or equal to `/^@[a-z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._right_vector = right_vector

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaFormula1And):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DevicegroupSchemaLogging(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'i_agent': 'DevicegroupSchemaLoggingIAgent',
        'log_level': 'str',
        'native_gpb': 'DevicegroupSchemaLoggingNativegpb',
        'non_sensor_rules': 'DevicegroupSchemaLoggingNonsensorrules',
        'open_config': 'DevicegroupSchemaLoggingOpenconfig',
        'server_monitoring': 'DevicegroupSchemaLoggingServermonitoring',
        'reports_generation': 'DevicegroupSchemaLoggingReportsgeneration',
        'snmp': 'DevicegroupSchemaLoggingSnmp',
        'trigger_evaluation': 'DevicegroupSchemaLoggingTriggerevaluation',
        'ml_model_builder': 'DevicegroupSchemaLoggingMLmodelbuilder',
        'resource_discovery': 'DevicegroupSchemaLoggingResourcediscovery',
        'flow': 'DevicegroupSchemaLoggingFlow',
        'sflow': 'DevicegroupSchemaLoggingSflow',
        'byoi': 'DevicegroupSchemaLoggingByoi',
        'snmp_notification': 'DevicegroupSchemaLoggingSnmpnotification',
        'syslog': 'DevicegroupSchemaLoggingSyslog'
    }

    attribute_map = {
        'i_agent': 'iAgent',
        'log_level': 'log-level',
        'native_gpb': 'native-gpb',
        'non_sensor_rules': 'non-sensor-rules',
        'open_config': 'open-config',
        'server_monitoring': 'server-monitoring',
        'reports_generation': 'reports-generation',
        'snmp': 'snmp',
        'trigger_evaluation': 'trigger-evaluation',
        'ml_model_builder': 'ML-model-builder',
        'resource_discovery': 'resource-discovery',
        'flow': 'flow',
        'sflow': 'sflow',
        'byoi': 'byoi',
        'snmp_notification': 'snmp-notification',
        'syslog': 'syslog'
    }

    def __init__(self, i_agent=None, log_level=None, native_gpb=None, non_sensor_rules=None, open_config=None, server_monitoring=None, reports_generation=None, snmp=None, trigger_evaluation=None, ml_model_builder=None, resource_discovery=None, flow=None, sflow=None, byoi=None, snmp_notification=None, syslog=None):  # noqa: E501
        """DevicegroupSchemaLogging - a model defined in Swagger"""  # noqa: E501

        self._i_agent = None
        self._log_level = None
        self._native_gpb = None
        self._non_sensor_rules = None
        self._open_config = None
        self._server_monitoring = None
        self._reports_generation = None
        self._snmp = None
        self._trigger_evaluation = None
        self._ml_model_builder = None
        self._resource_discovery = None
        self._flow = None
        self._sflow = None
        self._byoi = None
        self._snmp_notification = None
        self._syslog = None
        self.discriminator = None

        if i_agent is not None:
            self.i_agent = i_agent
        if log_level is not None:
            self.log_level = log_level
        if native_gpb is not None:
            self.native_gpb = native_gpb
        if non_sensor_rules is not None:
            self.non_sensor_rules = non_sensor_rules
        if open_config is not None:
            self.open_config = open_config
        if server_monitoring is not None:
            self.server_monitoring = server_monitoring
        if reports_generation is not None:
            self.reports_generation = reports_generation
        if snmp is not None:
            self.snmp = snmp
        if trigger_evaluation is not None:
            self.trigger_evaluation = trigger_evaluation
        if ml_model_builder is not None:
            self.ml_model_builder = ml_model_builder
        if resource_discovery is not None:
            self.resource_discovery = resource_discovery
        if flow is not None:
            self.flow = flow
        if sflow is not None:
            self.sflow = sflow
        if byoi is not None:
            self.byoi = byoi
        if snmp_notification is not None:
            self.snmp_notification = snmp_notification
        if syslog is not None:
            self.syslog = syslog

    @property
    def i_agent(self):
        """Gets the i_agent of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The i_agent of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingIAgent
        """
        return self._i_agent

    @i_agent.setter
    def i_agent(self, i_agent):
        """Sets the i_agent of this DevicegroupSchemaLogging.


        :param i_agent: The i_agent of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingIAgent
        """

        self._i_agent = i_agent

    @property
    def log_level(self):
        """Gets the log_level of this DevicegroupSchemaLogging.  # noqa: E501

        Global log level  # noqa: E501

        :return: The log_level of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: str
        """
        return self._log_level

    @log_level.setter
    def log_level(self, log_level):
        """Sets the log_level of this DevicegroupSchemaLogging.

        Global log level  # noqa: E501

        :param log_level: The log_level of this DevicegroupSchemaLogging.  # noqa: E501
        :type: str
        """
        allowed_values = ["error", "debug", "warn", "info"]  # noqa: E501
        if log_level not in allowed_values:
            raise ValueError(
                "Invalid value for `log_level` ({0}), must be one of {1}"  # noqa: E501
                .format(log_level, allowed_values)
            )

        self._log_level = log_level

    @property
    def native_gpb(self):
        """Gets the native_gpb of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The native_gpb of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingNativegpb
        """
        return self._native_gpb

    @native_gpb.setter
    def native_gpb(self, native_gpb):
        """Sets the native_gpb of this DevicegroupSchemaLogging.


        :param native_gpb: The native_gpb of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingNativegpb
        """

        self._native_gpb = native_gpb

    @property
    def non_sensor_rules(self):
        """Gets the non_sensor_rules of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The non_sensor_rules of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingNonsensorrules
        """
        return self._non_sensor_rules

    @non_sensor_rules.setter
    def non_sensor_rules(self, non_sensor_rules):
        """Sets the non_sensor_rules of this DevicegroupSchemaLogging.


        :param non_sensor_rules: The non_sensor_rules of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingNonsensorrules
        """

        self._non_sensor_rules = non_sensor_rules

    @property
    def open_config(self):
        """Gets the open_config of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The open_config of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingOpenconfig
        """
        return self._open_config

    @open_config.setter
    def open_config(self, open_config):
        """Sets the open_config of this DevicegroupSchemaLogging.


        :param open_config: The open_config of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingOpenconfig
        """

        self._open_config = open_config

    @property
    def server_monitoring(self):
        """Gets the server_monitoring of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The server_monitoring of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingServermonitoring
        """
        return self._server_monitoring

    @server_monitoring.setter
    def server_monitoring(self, server_monitoring):
        """Sets the server_monitoring of this DevicegroupSchemaLogging.


        :param server_monitoring: The server_monitoring of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingServermonitoring
        """

        self._server_monitoring = server_monitoring

    @property
    def reports_generation(self):
        """Gets the reports_generation of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The reports_generation of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingReportsgeneration
        """
        return self._reports_generation

    @reports_generation.setter
    def reports_generation(self, reports_generation):
        """Sets the reports_generation of this DevicegroupSchemaLogging.


        :param reports_generation: The reports_generation of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingReportsgeneration
        """

        self._reports_generation = reports_generation

    @property
    def snmp(self):
        """Gets the snmp of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The snmp of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingSnmp
        """
        return self._snmp

    @snmp.setter
    def snmp(self, snmp):
        """Sets the snmp of this DevicegroupSchemaLogging.


        :param snmp: The snmp of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingSnmp
        """

        self._snmp = snmp

    @property
    def trigger_evaluation(self):
        """Gets the trigger_evaluation of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The trigger_evaluation of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingTriggerevaluation
        """
        return self._trigger_evaluation

    @trigger_evaluation.setter
    def trigger_evaluation(self, trigger_evaluation):
        """Sets the trigger_evaluation of this DevicegroupSchemaLogging.


        :param trigger_evaluation: The trigger_evaluation of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingTriggerevaluation
        """

        self._trigger_evaluation = trigger_evaluation

    @property
    def ml_model_builder(self):
        """Gets the ml_model_builder of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The ml_model_builder of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingMLmodelbuilder
        """
        return self._ml_model_builder

    @ml_model_builder.setter
    def ml_model_builder(self, ml_model_builder):
        """Sets the ml_model_builder of this DevicegroupSchemaLogging.


        :param ml_model_builder: The ml_model_builder of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingMLmodelbuilder
        """

        self._ml_model_builder = ml_model_builder

    @property
    def resource_discovery(self):
        """Gets the resource_discovery of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The resource_discovery of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingResourcediscovery
        """
        return self._resource_discovery

    @resource_discovery.setter
    def resource_discovery(self, resource_discovery):
        """Sets the resource_discovery of this DevicegroupSchemaLogging.


        :param resource_discovery: The resource_discovery of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingResourcediscovery
        """

        self._resource_discovery = resource_discovery

    @property
    def flow(self):
        """Gets the flow of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The flow of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingFlow
        """
        return self._flow

    @flow.setter
    def flow(self, flow):
        """Sets the flow of this DevicegroupSchemaLogging.


        :param flow: The flow of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingFlow
        """

        self._flow = flow

    @property
    def sflow(self):
        """Gets the sflow of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The sflow of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingSflow
        """
        return self._sflow

    @sflow.setter
    def sflow(self, sflow):
        """Sets the sflow of this DevicegroupSchemaLogging.


        :param sflow: The sflow of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingSflow
        """

        self._sflow = sflow

    @property
    def byoi(self):
        """Gets the byoi of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The byoi of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingByoi
        """
        return self._byoi

    @byoi.setter
    def byoi(self, byoi):
        """Sets the byoi of this DevicegroupSchemaLogging.


        :param byoi: The byoi of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingByoi
        """

        self._byoi = byoi

    @property
    def snmp_notification(self):
        """Gets the snmp_notification of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The snmp_notification of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingSnmpnotification
        """
        return self._snmp_notification

    @snmp_notification.setter
    def snmp_notification(self, snmp_notification):
        """Sets the snmp_notification of this DevicegroupSchemaLogging.


        :param snmp_notification: The snmp_notification of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingSnmpnotification
        """

        self._snmp_notification = snmp_notification

    @property
    def syslog(self):
        """Gets the syslog of this DevicegroupSchemaLogging.  # noqa: E501


        :return: The syslog of this DevicegroupSchemaLogging.  # noqa: E501
        :rtype: DevicegroupSchemaLoggingSyslog
        """
        return self._syslog

    @syslog.setter
    def syslog(self, syslog):
        """Sets the syslog of this DevicegroupSchemaLogging.


        :param syslog: The syslog of this DevicegroupSchemaLogging.  # noqa: E501
        :type: DevicegroupSchemaLoggingSyslog
        """

        self._syslog = syslog

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DevicegroupSchemaLogging, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicegroupSchemaLogging):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class NotificationSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'http_post': 'NotificationSchemaHttppost',
        'notification_name': 'str',
        'slack': 'NotificationSchemaSlack',
        'microsoft_teams': 'NotificationSchemaMicrosoftteams',
        'emails': 'NotificationSchemaEmails',
        'kafka_publish': 'NotificationSchemaKafkapublish',
        'amqp_publish': 'NotificationSchemaAmqppublish'
    }

    attribute_map = {
        'description': 'description',
        'http_post': 'http-post',
        'notification_name': 'notification-name',
        'slack': 'slack',
        'microsoft_teams': 'microsoft-teams',
        'emails': 'emails',
        'kafka_publish': 'kafka-publish',
        'amqp_publish': 'amqp-publish'
    }

    def __init__(self, description=None, http_post=None, notification_name=None, slack=None, microsoft_teams=None, emails=None, kafka_publish=None, amqp_publish=None):  # noqa: E501
        """NotificationSchema - a model defined in Swagger"""  # noqa: E501

        self._description = None
        self._http_post = None
        self._notification_name = None
        self._slack = None
        self._microsoft_teams = None
        self._emails = None
        self._kafka_publish = None
        self._amqp_publish = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if http_post is not None:
            self.http_post = http_post
        self.notification_name = notification_name
        if slack is not None:
            self.slack = slack
        if microsoft_teams is not None:
            self.microsoft_teams = microsoft_teams
        if emails is not None:
            self.emails = emails
        if kafka_publish is not None:
            self.kafka_publish = kafka_publish
        if amqp_publish is not None:
            self.amqp_publish = amqp_publish

    @property
    def description(self):
        """Gets the description of this NotificationSchema.  # noqa: E501

        Description about the notification  # noqa: E501

        :return: The description of this NotificationSchema.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this NotificationSchema.

        Description about the notification  # noqa: E501

        :param description: The description of this NotificationSchema.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def http_post(self):
        """Gets the http_post of this NotificationSchema.  # noqa: E501


        :return: The http_post of this NotificationSchema.  # noqa: E501
        :rtype: NotificationSchemaHttppost
        """
        return self._http_post

    @http_post.setter
    def http_post(self, http_post):
        """Sets the http_post of this NotificationSchema.


        :param http_post: The http_post of this NotificationSchema.  # noqa: E501
        :type: NotificationSchemaHttppost
        """

        self._http_post = http_post

    @property
    def notification_name(self):
        """Gets the notification_name of this NotificationSchema.  # noqa: E501

        Name of the notification. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The notification_name of this NotificationSchema.  # noqa: E501
        :rtype: str
        """
        return self._notification_name

    @notification_name.setter
    def notification_name(self, notification_name):
        """Sets the notification_name of this NotificationSchema.

        Name of the notification. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param notification_name: The notification_name of this NotificationSchema.  # noqa: E501
        :type: str
        """
        if notification_name is None:
            raise ValueError("Invalid value for `notification_name`, must not be `None`")  # noqa: E501
        if notification_name is not None and len(notification_name) > 64:
            raise ValueError("Invalid value for `notification_name`, length must be less than or equal to `64`")  # noqa: E501
        if notification_name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', notification_name):  # noqa: E501
            raise ValueError(r"Invalid value for `notification_name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._notification_name = notification_name

    @property
    def slack(self):
        """Gets the slack of this NotificationSchema.  # noqa: E501


        :return: The slack of this NotificationSchema.  # noqa: E501
        :rtype: NotificationSchemaSlack
        """
        return self._slack

    @slack.setter
    def slack(self, slack):
        """Sets the slack of this NotificationSchema.


        :param slack: The slack of this NotificationSchema.  # noqa: E501
        :type: NotificationSchemaSlack
        """

        self._slack = slack

    @property
    def microsoft_teams(self):
        """Gets the microsoft_teams of this NotificationSchema.  # noqa: E501


        :return: The microsoft_teams of this NotificationSchema.  # noqa: E501
        :rtype: NotificationSchemaMicrosoftteams
        """
        return self._microsoft_teams

    @microsoft_teams.setter
    def microsoft_teams(self, microsoft_teams):
        """Sets the microsoft_teams of this NotificationSchema.


        :param microsoft_teams: The microsoft_teams of this NotificationSchema.  # noqa: E501
        :type: NotificationSchemaMicrosoftteams
        """

        self._microsoft_teams = microsoft_teams

    @property
    def emails(self):
        """Gets the emails of this NotificationSchema.  # noqa: E501


        :return: The emails of this NotificationSchema.  # noqa: E501
        :rtype: NotificationSchemaEmails
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """Sets the emails of this NotificationSchema.


        :param emails: The emails of this NotificationSchema.  # noqa: E501
        :type: NotificationSchemaEmails
        """

        self._emails = emails

    @property
    def kafka_publish(self):
        """Gets the kafka_publish of this NotificationSchema.  # noqa: E501


        :return: The kafka_publish of this NotificationSchema.  # noqa: E501
        :rtype: NotificationSchemaKafkapublish
        """
        return self._kafka_publish

    @kafka_publish.setter
    def kafka_publish(self, kafka_publish):
        """Sets the kafka_publish of this NotificationSchema.


        :param kafka_publish: The kafka_publish of this NotificationSchema.  # noqa: E501
        :type: NotificationSchemaKafkapublish
        """

        self._kafka_publish = kafka_publish

    @property
    def amqp_publish(self):
        """Gets the amqp_publish of this NotificationSchema.  # noqa: E501


        :return: The amqp_publish of this NotificationSchema.  # noqa: E501
        :rtype: NotificationSchemaAmqppublish
        """
        return self._amqp_publish

    @amqp_publish.setter
    def amqp_publish(self, amqp_publish):
        """Sets the amqp_publish of this NotificationSchema.


        :param amqp_publish: The amqp_publish of this NotificationSchema.  # noqa: E501
        :type: NotificationSchemaAmqppublish
        """

        self._amqp_publish = amqp_publish

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NotificationSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SyslogSchemaSyslog(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'port': 'int',
        'header_pattern': 'list[HeaderPatternSchema]',
        'pattern': 'list[PatternSchema]',
        'pattern_set': 'list[PatternSetSchema]'
    }

    attribute_map = {
        'port': 'port',
        'header_pattern': 'header-pattern',
        'pattern': 'pattern',
        'pattern_set': 'pattern-set'
    }

    def __init__(self, port=None, header_pattern=None, pattern=None, pattern_set=None):  # noqa: E501
        """SyslogSchemaSyslog - a model defined in Swagger"""  # noqa: E501

        self._port = None
        self._header_pattern = None
        self._pattern = None
        self._pattern_set = None
        self.discriminator = None

        if port is not None:
            self.port = port
        if header_pattern is not None:
            self.header_pattern = header_pattern
        if pattern is not None:
            self.pattern = pattern
        if pattern_set is not None:
            self.pattern_set = pattern_set

    @property
    def port(self):
        """Gets the port of this SyslogSchemaSyslog.  # noqa: E501

        Port to listen for syslog messages, default is 514  # noqa: E501

        :return: The port of this SyslogSchemaSyslog.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this SyslogSchemaSyslog.

        Port to listen for syslog messages, default is 514  # noqa: E501

        :param port: The port of this SyslogSchemaSyslog.  # noqa: E501
        :type: int
        """

        self._port = port

    @property
    def header_pattern(self):
        """Gets the header_pattern of this SyslogSchemaSyslog.  # noqa: E501


        :return: The header_pattern of this SyslogSchemaSyslog.  # noqa: E501
        :rtype: list[HeaderPatternSchema]
        """
        return self._header_pattern

    @header_pattern.setter
    def header_pattern(self, header_pattern):
        """Sets the header_pattern of this SyslogSchemaSyslog.


        :param header_pattern: The header_pattern of this SyslogSchemaSyslog.  # noqa: E501
        :type: list[HeaderPatternSchema]
        """

        self._header_pattern = header_pattern

    @property
    def pattern(self):
        """Gets the pattern of this SyslogSchemaSyslog.  # noqa: E501


        :return: The pattern of this SyslogSchemaSyslog.  # noqa: E501
        :rtype: list[PatternSchema]
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this SyslogSchemaSyslog.


        :param pattern: The pattern of this SyslogSchemaSyslog.  # noqa: E501
        :type: list[PatternSchema]
        """

        self._pattern = pattern

    @property
    def pattern_set(self):
        """Gets the pattern_set of this SyslogSchemaSyslog.  # noqa: E501


        :return: The pattern_set of this SyslogSchemaSyslog.  # noqa: E501
        :rtype: list[PatternSetSchema]
        """
        return self._pattern_set

    @pattern_set.setter
    def pattern_set(self, pattern_set):
        """Sets the pattern_set of this SyslogSchemaSyslog.


        :param pattern_set: The pattern_set of this SyslogSchemaSyslog.  # noqa: E501
        :type: list[PatternSetSchema]
        """

        self._pattern_set = pattern_set

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SyslogSchemaSyslog, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyslogSchemaSyslog):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RollupSummarizationSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'profile_id': 'str',
        'rule': 'list[RollupsummarizationSchemaRule]',
        'database': 'list[RollupsummarizationSchemaDatabase]',
        'data_rollup_order': 'list[RollupsummarizationSchemaDatarolluporder]'
    }

    attribute_map = {
        'profile_id': 'profile-id',
        'rule': 'rule',
        'database': 'database',
        'data_rollup_order': 'data-rollup-order'
    }

    def __init__(self, profile_id=None, rule=None, database=None, data_rollup_order=None):  # noqa: E501
        """RollupSummarizationSchema - a model defined in Swagger"""  # noqa: E501

        self._profile_id = None
        self._rule = None
        self._database = None
        self._data_rollup_order = None
        self.discriminator = None

        if profile_id is not None:
            self.profile_id = profile_id
        if rule is not None:
            self.rule = rule
        if database is not None:
            self.database = database
        if data_rollup_order is not None:
            self.data_rollup_order = data_rollup_order

    @property
    def profile_id(self):
        """Gets the profile_id of this RollupSummarizationSchema.  # noqa: E501

        Profile-id of data rollup summarization instance. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The profile_id of this RollupSummarizationSchema.  # noqa: E501
        :rtype: str
        """
        return self._profile_id

    @profile_id.setter
    def profile_id(self, profile_id):
        """Sets the profile_id of this RollupSummarizationSchema.

        Profile-id of data rollup summarization instance. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param profile_id: The profile_id of this RollupSummarizationSchema.  # noqa: E501
        :type: str
        """
        if profile_id is not None and len(profile_id) > 64:
            raise ValueError("Invalid value for `profile_id`, length must be less than or equal to `64`")  # noqa: E501
        if profile_id is not None and len(profile_id) < 1:
            raise ValueError("Invalid value for `profile_id`, length must be greater than or equal to `1`")  # noqa: E501
        if profile_id is not None and not re.search(r'^[a-zA-Z0-9]([a-zA-Z0-9_-]*\\.*)*$', profile_id):  # noqa: E501
            raise ValueError(r"Invalid value for `profile_id`, must be a follow pattern or equal to `/^[a-zA-Z0-9]([a-zA-Z0-9_-]*\\.*)*$/`")  # noqa: E501

        self._profile_id = profile_id

    @property
    def rule(self):
        """Gets the rule of this RollupSummarizationSchema.  # noqa: E501


        :return: The rule of this RollupSummarizationSchema.  # noqa: E501
        :rtype: list[RollupsummarizationSchemaRule]
        """
        return self._rule

    @rule.setter
    def rule(self, rule):
        """Sets the rule of this RollupSummarizationSchema.


        :param rule: The rule of this RollupSummarizationSchema.  # noqa: E501
        :type: list[RollupsummarizationSchemaRule]
        """

        self._rule = rule

    @property
    def database(self):
        """Gets the database of this RollupSummarizationSchema.  # noqa: E501


        :return: The database of this RollupSummarizationSchema.  # noqa: E501
        :rtype: list[RollupsummarizationSchemaDatabase]
        """
        return self._database

    @database.setter
    def database(self, database):
        """Sets the database of this RollupSummarizationSchema.


        :param database: The database of this RollupSummarizationSchema.  # noqa: E501
        :type: list[RollupsummarizationSchemaDatabase]
        """

        self._database = database

    @property
    def data_rollup_order(self):
        """Gets the data_rollup_order of this RollupSummarizationSchema.  # noqa: E501

        List of data-roll up orders  # noqa: E501

        :return: The data_rollup_order of this RollupSummarizationSchema.  # noqa: E501
        :rtype: list[RollupsummarizationSchemaDatarolluporder]
        """
        return self._data_rollup_order

    @data_rollup_order.setter
    def data_rollup_order(self, data_rollup_order):
        """Sets the data_rollup_order of this RollupSummarizationSchema.

        List of data-roll up orders  # noqa: E501

        :param data_rollup_order: The data_rollup_order of this RollupSummarizationSchema.  # noqa: E501
        :type: list[RollupsummarizationSchemaDatarolluporder]
        """

        self._data_rollup_order = data_rollup_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RollupSummarizationSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RollupSummarizationSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SnmpnotificationSchemaSnmpnotification(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'engine_id': 'str',
        'port': 'int',
        'v3': 'SnmpnotificationSchemaSnmpnotificationV3'
    }

    attribute_map = {
        'engine_id': 'engine-id',
        'port': 'port',
        'v3': 'v3'
    }

    def __init__(self, engine_id=None, port=None, v3=None):  # noqa: E501
        """SnmpnotificationSchemaSnmpnotification - a model defined in Swagger"""  # noqa: E501

        self._engine_id = None
        self._port = None
        self._v3 = None
        self.discriminator = None

        if engine_id is not None:
            self.engine_id = engine_id
        if port is not None:
            self.port = port
        if v3 is not None:
            self.v3 = v3

    @property
    def engine_id(self):
        """Gets the engine_id of this SnmpnotificationSchemaSnmpnotification.  # noqa: E501

        Autogenerated Engine-id for Healthbot in Hex Format Eg: '80001f8880bd5b8d052eb40d6000000000'  # noqa: E501

        :return: The engine_id of this SnmpnotificationSchemaSnmpnotification.  # noqa: E501
        :rtype: str
        """
        return self._engine_id

    @engine_id.setter
    def engine_id(self, engine_id):
        """Sets the engine_id of this SnmpnotificationSchemaSnmpnotification.

        Autogenerated Engine-id for Healthbot in Hex Format Eg: '80001f8880bd5b8d052eb40d6000000000'  # noqa: E501

        :param engine_id: The engine_id of this SnmpnotificationSchemaSnmpnotification.  # noqa: E501
        :type: str
        """
        if engine_id is not None and len(engine_id) > 64:
            raise ValueError("Invalid value for `engine_id`, length must be less than or equal to `64`")  # noqa: E501
        if engine_id is not None and len(engine_id) < 5:
            raise ValueError("Invalid value for `engine_id`, length must be greater than or equal to `5`")  # noqa: E501

        self._engine_id = engine_id

    @property
    def port(self):
        """Gets the port of this SnmpnotificationSchemaSnmpnotification.  # noqa: E501

        Port to listen for SNMP Notification(Traps/Informs) messages  # noqa: E501

        :return: The port of this SnmpnotificationSchemaSnmpnotification.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this SnmpnotificationSchemaSnmpnotification.

        Port to listen for SNMP Notification(Traps/Informs) messages  # noqa: E501

        :param port: The port of this SnmpnotificationSchemaSnmpnotification.  # noqa: E501
        :type: int
        """

        self._port = port

    @property
    def v3(self):
        """Gets the v3 of this SnmpnotificationSchemaSnmpnotification.  # noqa: E501


        :return: The v3 of this SnmpnotificationSchemaSnmpnotification.  # noqa: E501
        :rtype: SnmpnotificationSchemaSnmpnotificationV3
        """
        return self._v3

    @v3.setter
    def v3(self, v3):
        """Sets the v3 of this SnmpnotificationSchemaSnmpnotification.


        :param v3: The v3 of this SnmpnotificationSchemaSnmpnotification.  # noqa: E501
        :type: SnmpnotificationSchemaSnmpnotificationV3
        """

        self._v3 = v3

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SnmpnotificationSchemaSnmpnotification, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SnmpnotificationSchemaSnmpnotification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SflowSchemaSflowField(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'export_as': 'str',
        'field_name': 'str',
        'next_header': 'list[ERRORUNKNOWN]',
        'size_based_on_field': 'SflowSchemaSflowSizebasedonfield',
        'size_in_bits': 'int',
        'type': 'str'
    }

    attribute_map = {
        'description': 'description',
        'export_as': 'export-as',
        'field_name': 'field-name',
        'next_header': 'next-header',
        'size_based_on_field': 'size-based-on-field',
        'size_in_bits': 'size-in-bits',
        'type': 'type'
    }

    def __init__(self, description=None, export_as=None, field_name=None, next_header=None, size_based_on_field=None, size_in_bits=None, type=None):  # noqa: E501
        """SflowSchemaSflowField - a model defined in Swagger"""  # noqa: E501

        self._description = None
        self._export_as = None
        self._field_name = None
        self._next_header = None
        self._size_based_on_field = None
        self._size_in_bits = None
        self._type = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if export_as is not None:
            self.export_as = export_as
        self.field_name = field_name
        if next_header is not None:
            self.next_header = next_header
        if size_based_on_field is not None:
            self.size_based_on_field = size_based_on_field
        if size_in_bits is not None:
            self.size_in_bits = size_in_bits
        if type is not None:
            self.type = type

    @property
    def description(self):
        """Gets the description of this SflowSchemaSflowField.  # noqa: E501

        Description of field  # noqa: E501

        :return: The description of this SflowSchemaSflowField.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SflowSchemaSflowField.

        Description of field  # noqa: E501

        :param description: The description of this SflowSchemaSflowField.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def export_as(self):
        """Gets the export_as of this SflowSchemaSflowField.  # noqa: E501

        Export field as tag/field  # noqa: E501

        :return: The export_as of this SflowSchemaSflowField.  # noqa: E501
        :rtype: str
        """
        return self._export_as

    @export_as.setter
    def export_as(self, export_as):
        """Sets the export_as of this SflowSchemaSflowField.

        Export field as tag/field  # noqa: E501

        :param export_as: The export_as of this SflowSchemaSflowField.  # noqa: E501
        :type: str
        """
        allowed_values = ["tag", "field"]  # noqa: E501
        if export_as not in allowed_values:
            raise ValueError(
                "Invalid value for `export_as` ({0}), must be one of {1}"  # noqa: E501
                .format(export_as, allowed_values)
            )

        self._export_as = export_as

    @property
    def field_name(self):
        """Gets the field_name of this SflowSchemaSflowField.  # noqa: E501

        Field name that needs to be exported  # noqa: E501

        :return: The field_name of this SflowSchemaSflowField.  # noqa: E501
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """Sets the field_name of this SflowSchemaSflowField.

        Field name that needs to be exported  # noqa: E501

        :param field_name: The field_name of this SflowSchemaSflowField.  # noqa: E501
        :type: str
        """
        if field_name is None:
            raise ValueError("Invalid value for `field_name`, must not be `None`")  # noqa: E501

        self._field_name = field_name

    @property
    def next_header(self):
        """Gets the next_header of this SflowSchemaSflowField.  # noqa: E501

        Flag to indicate current field points to next header format  # noqa: E501

        :return: The next_header of this SflowSchemaSflowField.  # noqa: E501
        :rtype: list[ERRORUNKNOWN]
        """
        return self._next_header

    @next_header.setter
    def next_header(self, next_header):
        """Sets the next_header of this SflowSchemaSflowField.

        Flag to indicate current field points to next header format  # noqa: E501

        :param next_header: The next_header of this SflowSchemaSflowField.  # noqa: E501
        :type: list[ERRORUNKNOWN]
        """

        self._next_header = next_header

    @property
    def size_based_on_field(self):
        """Gets the size_based_on_field of this SflowSchemaSflowField.  # noqa: E501


        :return: The size_based_on_field of this SflowSchemaSflowField.  # noqa: E501
        :rtype: SflowSchemaSflowSizebasedonfield
        """
        return self._size_based_on_field

    @size_based_on_field.setter
    def size_based_on_field(self, size_based_on_field):
        """Sets the size_based_on_field of this SflowSchemaSflowField.


        :param size_based_on_field: The size_based_on_field of this SflowSchemaSflowField.  # noqa: E501
        :type: SflowSchemaSflowSizebasedonfield
        """

        self._size_based_on_field = size_based_on_field

    @property
    def size_in_bits(self):
        """Gets the size_in_bits of this SflowSchemaSflowField.  # noqa: E501

        Field size in bits  # noqa: E501

        :return: The size_in_bits of this SflowSchemaSflowField.  # noqa: E501
        :rtype: int
        """
        return self._size_in_bits

    @size_in_bits.setter
    def size_in_bits(self, size_in_bits):
        """Sets the size_in_bits of this SflowSchemaSflowField.

        Field size in bits  # noqa: E501

        :param size_in_bits: The size_in_bits of this SflowSchemaSflowField.  # noqa: E501
        :type: int
        """

        self._size_in_bits = size_in_bits

    @property
    def type(self):
        """Gets the type of this SflowSchemaSflowField.  # noqa: E501

        Data type of field  # noqa: E501

        :return: The type of this SflowSchemaSflowField.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SflowSchemaSflowField.

        Data type of field  # noqa: E501

        :param type: The type of this SflowSchemaSflowField.  # noqa: E501
        :type: str
        """
        allowed_values = ["number", "string", "IpAddress", "hardwareAddr", "numbers", "ASPath"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SflowSchemaSflowField, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SflowSchemaSflowField):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
